yt.analysis_modules.halo_finding.halo_objects.LoadRockstarHalos.write_particle_lists — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.LoadRockstarHalos.write_particle_lists

`LoadRockstarHalos.` `write_particle_lists`(*args, **kwargs)

  Write out the particle data for halos to HDF5 files.

  This function will accept a filename prefix, and for every halo it will write out an HDF5 file containing the positions, velocities, indices and masses of the constituent particles. However, if the halo finder is run in parallel, halos will only be written out on the processors to which they belong. See Halo.write_particle_lists_txt for how to track these halos globally across files.

  Parameters: | prefix : String The prefix for the name(s) of the HDF5 files.

  Examples

      >>> halos.write_particle_lists("halo-parts")